@@ -2,6 +2,7 @@ use crate::module_loader::import_map::{url_for_path, vega_themes_url, vega_url,
 use crate::module_loader::VlConvertModuleLoader;
 use std::borrow::Cow;
 use std::collections::{HashMap, HashSet};
+use std::io::Cursor;
 use std::path::Path;
 use std::rc::Rc;
 use std::sync::{Arc, Mutex};
@@ -30,6 +31,8 @@ use png::{PixelDimensions, Unit};
 use tiny_skia::{Pixmap, PremultipliedColorU8};
 use usvg::{TreeParsing, TreeTextToPath};
 
+use image::io::Reader as ImageReader;
+
 use crate::text::{op_text_width, FONT_DB, USVG_OPTIONS};
 
 lazy_static! {
@@ -709,6 +712,29 @@ impl VlConverter {
         Self::svg_to_png(&svg, scale, ppi)
     }
 
+    pub async fn vega_to_jpeg(
+        &mut self,
+        vg_spec: serde_json::Value,
+        scale: Option<f32>,
+        quality: Option<u8>,
+    ) -> Result<Vec<u8>, AnyError> {
+        let scale = scale.unwrap_or(1.0);
+        let svg = self.vega_to_svg(vg_spec).await?;
+        Self::svg_to_jpeg(&svg, scale, quality)
+    }
+
+    pub async fn vegalite_to_jpeg(
+        &mut self,
+        vl_spec: serde_json::Value,
+        vl_opts: VlOpts,
+        scale: Option<f32>,
+        quality: Option<u8>,
+    ) -> Result<Vec<u8>, AnyError> {
+        let scale = scale.unwrap_or(1.0);
+        let svg = self.vegalite_to_svg(vl_spec, vl_opts).await?;
+        Self::svg_to_jpeg(&svg, scale, quality)
+    }
+
     fn svg_to_png(svg: &str, scale: f32, ppi: Option<f32>) -> Result<Vec<u8>, AnyError> {
         // default ppi to 72
         let ppi = ppi.unwrap_or(72.0);
@@ -751,6 +777,27 @@ impl VlConverter {
         }
     }
 
+    fn svg_to_jpeg(svg: &str, scale: f32, quality: Option<u8>) -> Result<Vec<u8>, AnyError> {
+        let png_bytes = Self::svg_to_png(svg, scale, None)?;
+        let img = ImageReader::new(Cursor::new(png_bytes))
+            .with_guessed_format()?
+            .decode()?;
+
+        let quality = quality.unwrap_or(90);
+        if quality > 100 {
+            bail!(
+                "JPEG quality parameter must be between 0 and 100 inclusive. Received: {quality}"
+            );
+        }
+
+        let mut jpeg_bytes: Vec<u8> = Vec::new();
+        img.write_to(
+            &mut Cursor::new(&mut jpeg_bytes),
+            image::ImageOutputFormat::Jpeg(quality),
+        )?;
+        Ok(jpeg_bytes)
+    }
+
     pub async fn get_local_tz(&mut self) -> Result<Option<String>, AnyError> {
         let (resp_tx, resp_rx) = oneshot::channel::<Result<Option<String>, AnyError>>();
         let cmd = VlConvertCommand::GetLocalTz { responder: resp_tx };
@@ -813,8 +860,18 @@ pub fn encode_png(pixmap: Pixmap, ppi: f32) -> Result<Vec<u8>, AnyError> {
     // due to rounding. So we stick with this method for now.
     for pixel in pixmap.pixels_mut() {
         let c = pixel.demultiply();
-        *pixel = PremultipliedColorU8::from_rgba(c.red(), c.green(), c.blue(), c.alpha())
-            .expect("from_rgba returned None");
+        let alpha = c.alpha();
+
+        // jonmmease: tiny-skia uses the private PremultipliedColorU8::from_rgba_unchecked here,
+        // but we need to use from_rgba, which checks to make sure r/g/b are less then or equal
+        // to alpha. Use min to ensure we don't trigger the check
+        *pixel = PremultipliedColorU8::from_rgba(
+            c.red().min(alpha),
+            c.green().min(alpha),
+            c.blue().min(alpha),
+            alpha,
+        )
+        .expect("Failed to construct PremultipliedColorU8 from rgba");
     }
 
     let mut data = Vec::new();
